===========================
Numba Enhancement Proposals
===========================

Numba Enhancement Proposals (not really abbreviated "NEPs", since "NEP"
is already taken by the Numpy project) describe proposed changes to Numba.
They are modeled on Python Enhancement Proposals (PEPs) and Numpy Enhancement
Proposals, and are typically written up when important changes
(behavioural changes, feature additions...) to Numba are proposed.

This page provides an overview of all proposals, making only a distinction
between the ones that have been implemented and those that have not been
implemented.

Implemented proposals
---------------------

.. toctree::
   :maxdepth: 1

   integer-typing.rst
   external-memory-management.rst

Other proposals
---------------

.. toctree::
   :maxdepth: 1

   extension-points.rst
   jit-classes.rst
   cfunc.rst
   type-inference.rst
   typing_recursion.rst

